############
Installation
############

Python & OS Support
###################

PyDocX is supported and tested with CPython versions 2.6, 2.7, 3.3, 3.4, and pypy.

PyDocX is supported and tested with Linux and Windows.

Install using pip
#################

.. code-block:: shell-session

    $ pip install pydocx

Upgrade using pip
#################

.. code-block:: shell-session

    $ pip install -U pydocx

